@@ -938,15 +938,20 @@ def query(ctx, query_command: List[str], reference_name: str, summary: bool, fea
 
     if summary:
         results_df = query.summary()
-    elif features_summary is not None:
-        results_df = query.features_summary(
-            kind=features_summary, ignore_annotations=not include_annotations).sort_values(
-            'Count', ascending=False).reset_index()
-    elif features_summary_unique is not None:
-        results_df = query.features_summary(
-            kind=features_summary_unique, selection='unique',
-            ignore_annotations=not include_annotations).sort_values(
-            'Count', ascending=False).reset_index()
+    elif features_summary is not None or features_summary_unique is not None:
+        if features_summary_unique is not None:
+            selection = 'unique'
+            kind = features_summary_unique
+        else:
+            selection = 'all'
+            kind = features_summary
+
+        if kind == 'mutation' or kind == 'mutations':
+            results_df = query.features_summary(kind=kind, selection=selection,
+                                                ignore_annotations=not include_annotations)
+        else:
+            results_df = query.features_summary(kind=kind, selection=selection)
+        results_df = results_df.sort_values('Count', ascending=False).reset_index()
     else:
         results_df = query.toframe(include_unknown=True)
 
