@@ -43,76 +43,78 @@ def test_summaries_loaded_data(loaded_database_genomic_data_store: GenomicsDataI
     assert 1 == gds.count_references()
     assert ['genome'] == gds.reference_names()
 
-    assert 111 == gds.count_mutations('genome')
-    assert 632 == gds.count_mutations('genome', include_unknown=True)
+    assert 112 == gds.count_mutations('genome')
+    assert 112 + 440 == gds.count_mutations('genome', include_unknown=True)
 
     # Mutations ignore unknown spdi
     ms = gds.mutations_summary('genome', id_type='spdi', ignore_annotations=True)
-    assert 111 == len(ms)
+    assert 112 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Count', 'Total', 'Percent'] == list(ms.columns)
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type', 'Count', 'Total', 'Percent'] == list(ms.columns)
 
     ## Convert percent to int to make it easier to compare in assert statements
     ms['Percent'] = ms['Percent'].astype(int)
 
-    assert ['reference', 839, 1, 'G', 2, 3, 66] == ms.loc['reference:839:1:G'].values.tolist()
-    assert ['reference', 866, 9, 'G', 1, 3, 33] == ms.loc['reference:866:9:G'].values.tolist()
-    assert ['reference', 1048, 1, 'G', 1, 3, 33] == ms.loc['reference:1048:1:G'].values.tolist()
-    assert ['reference', 3897, 5, 'G', 2, 3, 66] == ms.loc['reference:3897:5:G'].values.tolist()
+    assert ['reference', 839, 1, 'G', 'SNP', 2, 3, 66] == ms.loc['reference:839:1:G'].values.tolist()
+    assert ['reference', 866, 9, 'G', 'INDEL', 1, 3, 33] == ms.loc['reference:866:9:G'].values.tolist()
+    assert ['reference', 1048, 1, 'G', 'SNP', 1, 3, 33] == ms.loc['reference:1048:1:G'].values.tolist()
+    assert ['reference', 3897, 5, 'G', 'INDEL', 2, 3, 66] == ms.loc['reference:3897:5:G'].values.tolist()
 
     # Mutations include unknown spdi
     ms = gds.mutations_summary('genome', id_type='spdi', ignore_annotations=True, include_unknown=True)
-    assert 632 == len(ms)
+    assert 112 + 440 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Count', 'Total', 'Percent'] == list(ms.columns)
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type', 'Count', 'Total', 'Percent'] == list(ms.columns)
 
     ## Convert percent to int to make it easier to compare in assert statements
     ms['Percent'] = ms['Percent'].astype(int)
 
-    assert ['reference', 839, 1, 'G', 2, 3, 66] == ms.loc['reference:839:1:G'].values.tolist()
-    assert ['reference', 866, 9, 'G', 1, 3, 33] == ms.loc['reference:866:9:G'].values.tolist()
-    assert ['reference', 1048, 1, 'G', 1, 3, 33] == ms.loc['reference:1048:1:G'].values.tolist()
-    assert ['reference', 3897, 5, 'G', 2, 3, 66] == ms.loc['reference:3897:5:G'].values.tolist()
-    assert ['reference', 89, 1, '?', 3, 3, 100] == ms.loc['reference:89:1:?'].values.tolist()
-    assert ['reference', 5100, 1, '?', 2, 3, 66] == ms.loc['reference:5100:1:?'].values.tolist()
-    assert ['reference', 649, 1, '?', 1, 3, 33] == ms.loc['reference:649:1:?'].values.tolist()
+    assert ['reference', 839, 1, 'G', 'SNP', 2, 3, 66] == ms.loc['reference:839:1:G'].values.tolist()
+    assert ['reference', 866, 9, 'G', 'INDEL', 1, 3, 33] == ms.loc['reference:866:9:G'].values.tolist()
+    assert ['reference', 1048, 1, 'G', 'SNP', 1, 3, 33] == ms.loc['reference:1048:1:G'].values.tolist()
+    assert ['reference', 3897, 5, 'G', 'INDEL', 2, 3, 66] == ms.loc['reference:3897:5:G'].values.tolist()
+    assert ['reference', 89, 1, '?', 'UNKNOWN_MISSING', 3, 3, 100] == ms.loc['reference:89:1:?'].values.tolist()
+    assert ['reference', 5100, 1, '?', 'UNKNOWN_MISSING', 2, 3, 66] == ms.loc['reference:5100:1:?'].values.tolist()
+    assert ['reference', 649, 1, '?', 'UNKNOWN_MISSING', 1, 3, 33] == ms.loc['reference:649:1:?'].values.tolist()
 
     # Mutations spdi ref
     ms = gds.mutations_summary('genome', id_type='spdi_ref', ignore_annotations=True)
-    assert 111 == len(ms)
+    assert 112 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Count', 'Total', 'Percent'] == list(ms.columns)
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type', 'Count', 'Total', 'Percent'] == list(ms.columns)
 
     ## Convert percent to int to make it easier to compare in assert statements
     ms['Percent'] = ms['Percent'].astype(int)
 
-    assert ['reference', 839, 'C', 'G', 2, 3, 66] == ms.loc['reference:839:C:G'].values.tolist()
-    assert ['reference', 866, 'GCCAGATCC', 'G', 1, 3, 33] == ms.loc['reference:866:GCCAGATCC:G'].values.tolist()
-    assert ['reference', 1048, 'C', 'G', 1, 3, 33] == ms.loc['reference:1048:C:G'].values.tolist()
-    assert ['reference', 3897, 'GCGCA', 'G', 2, 3, 66] == ms.loc['reference:3897:GCGCA:G'].values.tolist()
+    assert ['reference', 839, 'C', 'G', 'SNP', 2, 3, 66] == ms.loc['reference:839:C:G'].values.tolist()
+    assert ['reference', 866, 'GCCAGATCC', 'G', 'INDEL', 1, 3, 33] == ms.loc[
+        'reference:866:GCCAGATCC:G'].values.tolist()
+    assert ['reference', 1048, 'C', 'G', 'SNP', 1, 3, 33] == ms.loc['reference:1048:C:G'].values.tolist()
+    assert ['reference', 3897, 'GCGCA', 'G', 'INDEL', 2, 3, 66] == ms.loc['reference:3897:GCGCA:G'].values.tolist()
 
     # Mutations spdi ref include unknowns
     ms = gds.mutations_summary('genome', id_type='spdi_ref', ignore_annotations=True, include_unknown=True)
-    assert 632 == len(ms)
+    assert 112 + 440 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Count', 'Total', 'Percent'] == list(ms.columns)
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type', 'Count', 'Total', 'Percent'] == list(ms.columns)
 
     ## Convert percent to int to make it easier to compare in assert statements
     ms['Percent'] = ms['Percent'].astype(int)
 
-    assert ['reference', 839, 'C', 'G', 2, 3, 66] == ms.loc['reference:839:C:G'].values.tolist()
-    assert ['reference', 866, 'GCCAGATCC', 'G', 1, 3, 33] == ms.loc['reference:866:GCCAGATCC:G'].values.tolist()
-    assert ['reference', 1048, 'C', 'G', 1, 3, 33] == ms.loc['reference:1048:C:G'].values.tolist()
-    assert ['reference', 3897, 'GCGCA', 'G', 2, 3, 66] == ms.loc['reference:3897:GCGCA:G'].values.tolist()
-    assert ['reference', 89, 'A', '?', 3, 3, 100] == ms.loc['reference:89:A:?'].values.tolist()
-    assert ['reference', 5100, 'T', '?', 2, 3, 66] == ms.loc['reference:5100:T:?'].values.tolist()
-    assert ['reference', 649, 'T', '?', 1, 3, 33] == ms.loc['reference:649:T:?'].values.tolist()
+    assert ['reference', 839, 'C', 'G', 'SNP', 2, 3, 66] == ms.loc['reference:839:C:G'].values.tolist()
+    assert ['reference', 866, 'GCCAGATCC', 'G', 'INDEL', 1, 3, 33] == ms.loc[
+        'reference:866:GCCAGATCC:G'].values.tolist()
+    assert ['reference', 1048, 'C', 'G', 'SNP', 1, 3, 33] == ms.loc['reference:1048:C:G'].values.tolist()
+    assert ['reference', 3897, 'GCGCA', 'G', 'INDEL', 2, 3, 66] == ms.loc['reference:3897:GCGCA:G'].values.tolist()
+    assert ['reference', 89, 'A', '?', 'UNKNOWN_MISSING', 3, 3, 100] == ms.loc['reference:89:A:?'].values.tolist()
+    assert ['reference', 5100, 'T', '?', 'UNKNOWN_MISSING', 2, 3, 66] == ms.loc['reference:5100:T:?'].values.tolist()
+    assert ['reference', 649, 'T', '?', 'UNKNOWN_MISSING', 1, 3, 33] == ms.loc['reference:649:T:?'].values.tolist()
 
     # Mutations include annotations (which should all be empty)
     ms = gds.mutations_summary('genome', id_type='spdi', ignore_annotations=False)
-    assert 111 == len(ms)
+    assert 112 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion',
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type',
             'Count', 'Total', 'Percent', 'Annotation', 'Annotation_Impact',
             'Gene_Name', 'Gene_ID', 'Feature_Type', 'Transcript_BioType',
             'HGVS.c', 'HGVS.p', 'ID_HGVS.c', 'ID_HGVS.p', 'ID_HGVS_GN.c', 'ID_HGVS_GN.p'] == list(ms.columns)
@@ -120,26 +122,26 @@ def test_summaries_loaded_data(loaded_database_genomic_data_store: GenomicsDataI
     ## Convert percent to int to make it easier to compare in assert statements
     ms['Percent'] = ms['Percent'].astype(int)
 
-    assert ['reference', 839, 1, 'G', 2, 3, 66] + ['NA'] * 12 == ms.loc['reference:839:1:G'].fillna(
+    assert ['reference', 839, 1, 'G', 'SNP', 2, 3, 66] + ['NA'] * 12 == ms.loc['reference:839:1:G'].fillna(
         'NA').values.tolist()
 
     # Test case of directly calling features_summary
     ms = gds.features_summary(kind='mutations', scope='genome', id_type='spdi', ignore_annotations=True)
-    assert 111 == len(ms)
+    assert 112 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Count', 'Total', 'Percent'] == list(ms.columns)
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type', 'Count', 'Total', 'Percent'] == list(ms.columns)
 
     ## Convert percent to int to make it easier to compare in assert statements
     ms['Percent'] = ms['Percent'].astype(int)
 
-    assert ['reference', 839, 1, 'G', 2, 3, 66] == ms.loc['reference:839:1:G'].values.tolist()
-    assert ['reference', 866, 9, 'G', 1, 3, 33] == ms.loc['reference:866:9:G'].values.tolist()
-    assert ['reference', 1048, 1, 'G', 1, 3, 33] == ms.loc['reference:1048:1:G'].values.tolist()
-    assert ['reference', 3897, 5, 'G', 2, 3, 66] == ms.loc['reference:3897:5:G'].values.tolist()
+    assert ['reference', 839, 1, 'G', 'SNP', 2, 3, 66] == ms.loc['reference:839:1:G'].values.tolist()
+    assert ['reference', 866, 9, 'G', 'INDEL', 1, 3, 33] == ms.loc['reference:866:9:G'].values.tolist()
+    assert ['reference', 1048, 1, 'G', 'SNP', 1, 3, 33] == ms.loc['reference:1048:1:G'].values.tolist()
+    assert ['reference', 3897, 5, 'G', 'INDEL', 2, 3, 66] == ms.loc['reference:3897:5:G'].values.tolist()
 
     # Test case of only including unknowns
     ms = gds.mutations_summary('genome', id_type='spdi', include_present=False, include_unknown=True)
-    assert 521 == len(ms)
+    assert 440 == len(ms)
     assert 'reference:649:1:?' in set(ms.index.tolist())
     assert 'reference:839:1:G' not in (ms.index.tolist())
 
@@ -223,7 +225,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
     ms = gds.mutations_summary('NC_011083', id_type='spdi', ignore_annotations=False)
     assert 177 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion',
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type',
             'Count', 'Total', 'Percent', 'Annotation', 'Annotation_Impact',
             'Gene_Name', 'Gene_ID', 'Feature_Type', 'Transcript_BioType',
             'HGVS.c', 'HGVS.p', 'ID_HGVS.c', 'ID_HGVS.p', 'ID_HGVS_GN.c', 'ID_HGVS_GN.p'] == list(ms.columns)
@@ -232,7 +234,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
     ms['Percent'] = ms['Percent'].astype(int)
 
     ## missense variant
-    assert ['NC_011083', 140658, 1, 'A', 3, 3, 100,
+    assert ['NC_011083', 140658, 1, 'A', 'SNP', 3, 3, 100,
             'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
             'c.497C>A', 'p.Ala166Glu',
             'hgvs:NC_011083:SEHA_RS01180:c.497C>A', 'hgvs:NC_011083:SEHA_RS01180:p.Ala166Glu',
@@ -240,7 +242,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
         ms.loc['NC_011083:140658:1:A'])
 
     ## inframe deletion
-    assert ['NC_011083', 4465400, len('GGCCGAA'), 'G', 3, 3, 100,
+    assert ['NC_011083', 4465400, len('GGCCGAA'), 'G', 'INDEL', 3, 3, 100,
             'conservative_inframe_deletion', 'MODERATE', 'tyrB', 'SEHA_RS22180', 'transcript', 'protein_coding',
             'c.157_162delGAAGCC', 'p.Glu53_Ala54del',
             'hgvs:NC_011083:SEHA_RS22180:c.157_162delGAAGCC', 'hgvs:NC_011083:SEHA_RS22180:p.Glu53_Ala54del',
@@ -248,7 +250,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
         ms.loc['NC_011083:4465400:7:G'])
 
     ## Intergenic variant (with some NA values in fields)
-    assert ['NC_011083', 4555461, len('T'), 'TC', 1, 3, 33,
+    assert ['NC_011083', 4555461, len('T'), 'TC', 'INDEL', 1, 3, 33,
             'intergenic_region', 'MODIFIER', 'SEHA_RS22510-SEHA_RS26685', 'SEHA_RS22510-SEHA_RS26685',
             'intergenic_region', 'NA',
             'n.4555461_4555462insC', 'NA',
@@ -259,7 +261,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
     ms = gds.mutations_summary('NC_011083', id_type='spdi_ref')
     assert 177 == len(ms)
     assert 'Mutation' == ms.index.name
-    assert ['Sequence', 'Position', 'Deletion', 'Insertion',
+    assert ['Sequence', 'Position', 'Deletion', 'Insertion', 'Type',
             'Count', 'Total', 'Percent', 'Annotation', 'Annotation_Impact',
             'Gene_Name', 'Gene_ID', 'Feature_Type', 'Transcript_BioType',
             'HGVS.c', 'HGVS.p', 'ID_HGVS.c', 'ID_HGVS.p', 'ID_HGVS_GN.c', 'ID_HGVS_GN.p'] == list(ms.columns)
@@ -268,7 +270,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
     ms['Percent'] = ms['Percent'].astype(int)
 
     ## missense variant
-    assert ['NC_011083', 140658, 'C', 'A', 3, 3, 100,
+    assert ['NC_011083', 140658, 'C', 'A', 'SNP', 3, 3, 100,
             'missense_variant', 'MODERATE', 'murF', 'SEHA_RS01180', 'transcript', 'protein_coding',
             'c.497C>A', 'p.Ala166Glu',
             'hgvs:NC_011083:SEHA_RS01180:c.497C>A', 'hgvs:NC_011083:SEHA_RS01180:p.Ala166Glu',
@@ -276,7 +278,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
         ms.loc['NC_011083:140658:C:A'])
 
     ## inframe deletion
-    assert ['NC_011083', 4465400, 'GGCCGAA', 'G', 3, 3, 100,
+    assert ['NC_011083', 4465400, 'GGCCGAA', 'G', 'INDEL', 3, 3, 100,
             'conservative_inframe_deletion', 'MODERATE', 'tyrB', 'SEHA_RS22180', 'transcript', 'protein_coding',
             'c.157_162delGAAGCC', 'p.Glu53_Ala54del',
             'hgvs:NC_011083:SEHA_RS22180:c.157_162delGAAGCC', 'hgvs:NC_011083:SEHA_RS22180:p.Glu53_Ala54del',
@@ -284,7 +286,7 @@ def test_summaries_variant_annotations(loaded_database_genomic_data_store_annota
         ms.loc['NC_011083:4465400:GGCCGAA:G'])
 
     ## Intergenic variant (with some NA values in fields)
-    assert ['NC_011083', 4555461, 'T', 'TC', 1, 3, 33,
+    assert ['NC_011083', 4555461, 'T', 'TC', 'INDEL', 1, 3, 33,
             'intergenic_region', 'MODIFIER', 'SEHA_RS22510-SEHA_RS26685', 'SEHA_RS22510-SEHA_RS26685',
             'intergenic_region', 'NA',
             'n.4555461_4555462insC', 'NA',
